'use strict';

const {createServer} = require('http');
const {parse} = require('url');
const next = require('next');
const pathMatch = require('path-match');

const port = parseInt(process.env.PORT, 10) || 7777;
const dev = process.env.NODE_ENV !== 'production';
const app = next({dev});
const handle = app.getRequestHandler();
const route = pathMatch();
const routes = require('./routes');

app.prepare()
    .then(() => {
        createServer((req, res) => {
            const {pathname, query} = parse(req.url, true);

            if (pathname === '/pages/') {
                app.render(req, res, '/pages/list');
                return;
            }

            let params;
            for (const [path, controller] of routes) {
                params = route(path)(pathname) || route(path + '/')(pathname);
                if (params) {
                    app.render(req, res, controller, Object.assign(params, query));
                    return;
                }
            }

            handle(req, res);
        })
            .listen(port, (err) => {
                if (err) { throw err; }
                console.log(`> Ready on http://localhost:${port}`);
            });
    });
